@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class EventConfig(AppConfig):
-    name = 'event'
+    name = 'push_notification.event'
